package com.etas.ascet.api.protocol;

import java.util.concurrent.ExecutionException;

import org.apache.commons.lang3.StringUtils;
import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.lsp4j.jsonrpc.ResponseErrorException;

import com.google.gson.JsonPrimitive;

/**
 * Extract information from {@link ResponseErrorException}
 */
@NonNullByDefault
public final class ResponseErrorUtil {

    private ResponseErrorUtil() {
        // nothing
    }

    /**
     * @param exception
     *            the exception
     * @return The stack trace from the ASCET API server
     */
    public String getServerStackTrace(final ExecutionException exception) {
        final Throwable cause = exception.getCause();
        if ((cause == null) || !(cause instanceof ResponseErrorException)) {
            return "";
        }
        return getServerStackTrace((ResponseErrorException) cause);
    }

    /**
     * @param exception
     *            the exception
     * @return The stack trace from the ASCET API server
     */
    public String getServerStackTrace(final ResponseErrorException exception) {
        final var data = (JsonPrimitive) exception.getResponseError().getData();
        return data.isString()
                ? StringUtils.defaultString(data.getAsString())
                : data.toString();
    }

    /**
     * @param exception
     *            the exception
     * @return The error code from the ASCET API server
     */
    public int getServerErrorCode(final ExecutionException exception) {
        final Throwable cause = exception.getCause();
        if ((cause == null) || !(cause instanceof ResponseErrorException)) {
            return 0;
        }
        return getServerErrorCode((ResponseErrorException) cause);
    }

    /**
     * @param exception
     *            the exception
     * @return The error code from the ASCET API server
     */
    public int getServerErrorCode(final ResponseErrorException exception) {
        return exception.getResponseError().getCode();
    }

}
