package com.etas.ascet.api.v1;

import org.eclipse.jdt.annotation.NonNullByDefault;

// CHECKSTYLE IGNORE JavadocType FOR NEXT 2 LINES
@NonNullByDefault
public final class LaunchOptionsV1 {

    private LaunchOptionsV1() {
        // hide ctor
    }

    /**
     * Allowed values: {@code CACHE_ON_THREAD_STACK, CACHE_IN_GLOBAL_RAM, CACHE_DISABLED}<br/>
     * This option defines how message values are handled during entering/leaving thread methods.
     * For concurrency reasons, they might need to be copied in a thread safe manner.
     */
    public static final String OPTION_MESSAGES_CACHE = "com.etas.ascet.build.messages.cache";

    /**
     * Value of option {@link #OPTION_MESSAGES_CACHE}
     */
    public static final String OPTION_MESSAGES_CACHE_VALUE_CACHE_ON_THREAD_STACK = "CACHE_ON_THREAD_STACK";

    /**
     * Value of option {@link #OPTION_MESSAGES_CACHE}
     */
    public static final String OPTION_MESSAGES_CACHE_VALUE_CACHE_IN_GLOBAL_RAM = "CACHE_IN_GLOBAL_RAM";

    /**
     * Value of option {@link #OPTION_MESSAGES_CACHE}
     */
    public static final String OPTION_MESSAGES_CACHE_VALUE_CACHE_DISABLED = "CACHE_DISABLED";

    /**
     * Option key for the launch type
     * The type of this option is {@code String}.
     */
    public static final String LAUNCH_TYPE = "com.etas.ascet.build.launch.type";

    public static final String LAUNCH_TYPE_ECU = "ECU";
    public static final String LAUNCH_TYPE_SIMULINK = "Simulink";
    public static final String LAUNCH_TYPE_FMU = "FMU";
    public static final String LAUNCH_TYPE_AUTOSAR = "AUTOSAR";
    public static final String LAUNCH_TYPE_EHOOKS = "EHOOKS";
    public static final String LAUNCH_TYPE_PC = "PC Experiment";
    public static final String LAUNCH_TYPE_EUNIT = "EUnit";
    public static final String LAUNCH_TYPE_RAPID_PROTOTYPING = "Rapid Prototyping";
    public static final String LAUNCH_NAME = "com.etas.ascet.build.launch.name";

    public static final String INTERPOLATION_SCHEME = "com.etas.ascet.build.interpolation.defaultScheme";
    public static final String INTERPOLATION_PATH = "com.etas.ascet.build.interpolation.definitionPath";
    public static final String CODE_GENERATOR_NAME = "com.etas.ascet.build.codeGenerator.name";
    public static final String CODE_GENERATOR_VERSION = "com.etas.ascet.build.codeGenerator.version";
    /**
     * Value <code>COMPONENT</code>/<code>SINGLE_MODULE</code><br/>
     * The default is <code>COMPONENT</code>, which means every component (class/struct/data interface) is generated
     * into its own source file.
     * The value <code>SINGLE_MODULE</code> forces all code to be generated into a single source module.
     */
    public static final String OUTPUT_FILE_STRUCTURE = "com.etas.ascet.build.output.fileStructure";
    /**
     * Value <code>true</code>/<code>false</code><br/>
     * If true, the output is generated as a project and the constant {@link #OUTPUT_PROJECT_NAME} must be used to
     * specify the projects workspace name.<br/>
     * If false, the output is written into a directory and the constant {@link #OUTPUT_FOLDER} must be used to specify
     * that folder.
     */
    public static final String OUTPUT_AS_PROJECT = "com.etas.ascet.build.output.project";
    /**
     * Path to a directory in the local file system to write the output to.<br/>
     * This option is only relevant when {@link #OUTPUT_AS_PROJECT} is <code>true</code>.
     */
    public static final String OUTPUT_FOLDER = "com.etas.ascet.build.output.folder";
    /**
     * Name of the output project to write the output to.
     * Eclipse variable expansion is supported. (e.g. <code>${project_loc}</code>)
     */
    public static final String OUTPUT_PROJECT_NAME = "com.etas.ascet.build.output.project.name";
    /**
     * Value <code>true</code>/<code>false</code><br/>
     * This option is only relevant when {@link #OUTPUT_AS_PROJECT} is <code>true</code>.
     * If <code>true</code>, the CDT nature is added to the generated project. CDT is the Eclipse C Development Tool
     * plugin.
     */
    public static final String OUTPUT_USE_CDT_NATURE = "com.etas.ascet.build.output.project.cdt";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * When <code>true</code>, the generated code does ignore configured representations. In the generated code,
     * symbol names that contain the representation name will then have a there a default name. Normally this is
     * {@code Physical}.
     */
    public static final String OPTIONS_PHYSICAL_IMPL = "com.etas.ascet.build.physicalImplementation";
    /**
     * Workspace path to the advanced options file.
     */
    public static final String ADVANCED_OPTIONS_FILE = "com.etas.ascet.build.advanced.options.file";
    public static final String TARGET_COMPILER_INLINE_DIRECTIVE = "com.etas.ascet.build.compiler.inlineDirective";
    public static final String TARGET_COMPILER_MEMORY_DIRECTIVE = "com.etas.ascet.build.compiler.memoryDirective";
    /**
     * defines a list of space separated compiler options
     */
    public static final String TARGET_COMPILER_COMPILE_OPTIONS = "com.etas.ascet.build.compiler.options";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * When <code>true</code>, the generated code does use the "legacy naming convention".
     * E.g. this means that the package structure of ESDL is not part of generated symbol names.
     * Therefore symbols, that are in different packages can produce name collisions and the user needs to take care
     * about this.
     */
    public static final String NAMING_USE_ASCET6_CONVENTION = "com.etas.ascet.build.naming.ascet6LegacyMode";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * If given in the launch configuration, then the value from the launch configuration logic is overridden.
     * When <code>true</code> is active, the memory sections for calibration are enforced to be non-const in the
     * generated code.
     */
    public static final String MEM_RAM_CALIBRATION = "com.etas.ascet.build.mem.ram.calibration";

    /**
     * Value of option {@link #FLOATING_POINT_PRECISION};
     */
    public static final String FLOATING_POINT_PRECISION_FLOAT32 = "float32";

    /**
     * Value of option {@link #FLOATING_POINT_PRECISION};
     */
    public static final String FLOATING_POINT_PRECISION_FLOAT64 = "float64";

    /**
     * Determines the default type for real values in the generated code.
     * Possible options are {@link #FLOATING_POINT_PRECISION_FLOAT32} or {@link #FLOATING_POINT_PRECISION_FLOAT64}.
     */
    public static final String FLOATING_POINT_PRECISION = "com.etas.ascet.build.defaultFloatingPointPrecision";

    public static final String EHB_CONTAINER_BUILD_PATH = "com.etas.ascet.ehb.container.build.path";
    public static final String EHB_ADDITIONAL_COMMANDS = "com.etas.ascet.ehb.additional.commands";

    public static final String RESOURCE_PATH = "com.etas.ascet.build.resource";
    public static final String APPLICATION_FILE = "com.etas.ascet.build.application.file";
    public static final String OUTPUT_LOG_FILE_PATH = "com.etas.ascet.build.output.log.file.path";
    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Enable the generation of XCP protocol code. Only relevant in PC experiment code.
     */
    public static final String XCP_PROTOCOL = "com.etas.ascet.build.protocol.xcp";
    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Enable the generation of L1 protocol code. Only relevant in PC experiment code.
     */
    public static final String L1_PROTOCOL = "com.etas.ascet.build.protocol.l1";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Only relevant in PC experiment code.
     */
    public static final String START_EXPERIMENT = "com.etas.ascet.build.experiment.start";
    public static final String ASAP2_SKIP_ENTRY_CLASS_NODES = "com.etas.ascet.build.asap2.skip.entry.class.nodes";
    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Enable the generation of the A2L output file.
     */
    public static final String ASAP2 = "com.etas.ascet.build.asap2";
    /**
     * Value one of the constants ASAP2_MODEL_PATH_*<br/>
     * The mode, how the model paths are composed in the A2L output file.
     */
    public static final String ASAP2_MODEL_PATH = "com.etas.ascet.build.asap2.model.path";
    /**
     * parent is on the left site of the child
     */
    public static final String ASAP2_MODEL_PATH_ROOT_FIRST = "ROOT_FIRST";
    /**
     * parent is on the right site of the child
     */
    public static final String ASAP2_MODEL_PATH_ROOT_LAST = "ROOT_LAST";
    /**
     * include root (project) node
     */
    public static final String ASAP2_MODEL_PATH_ROOT = "ROOT";
    /**
     * Include entry class node.
     */
    public static final String ASAP2_MODEL_PATH_ENTRY_CLASS_NODE = "ENTRY_CLASS_NODE";
    /**
     * skip package names and globals are generated without parent
     */
    public static final String ASAP2_MODEL_PATH_LEGACY = "LEGACY";

    /**
     * Value one of the ASAP2_VERSION_* constants<br/>
     * Use the specific version for the A2L generation.
     */
    public static final String ASAP2_VERSION = "com.etas.ascet.build.asap2.version";

    public static final String ASAP2_VERSION_V1_41 = "1.41";
    public static final String ASAP2_VERSION_V1_51 = "1.51";
    public static final String ASAP2_VERSION_V1_61 = "1.61";
    public static final String ASAP2_VERSION_V1_70 = "1.70";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     */
    public static final String ASAP2_USE_ELEMENT_UNIT_FOR_FORMULA =
            "com.etas.ascet.build.asap2.use.element.unit.for.formula";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Enable the generation of the operating system integration code.
     * Not supported by all code generations.
     */
    public static final String OS_TASKS_GENERATE = "com.etas.ascet.build.os.tasks.generate";
    /**
     * Value one of the constants OS_TASKS_TYPE_*<br/>
     * Choose the type of integration code to be generated.
     */
    public static final String OS_TASKS_TYPE = "com.etas.ascet.build.os.tasks.type";

    public static final String OS_TASKS_TYPE_AUTOSAR = "AUTOSAR";
    public static final String OS_TASKS_TYPE_OSEK = "OSEK";
    public static final String OS_TASKS_TYPE_RTA_OSEK = "RTA_OSEK";
    public static final String OS_TASKS_TYPE_GENERIC_OS = "GENERIC_OS";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * Enable the generation of the MDX output file.
     */
    public static final String MDX = "com.etas.ascet.build.mdx";

    /**
     * Value only {@link #MDX_VERSION_V130} is supported at the moment.<br/>
     * Set the version of the MDX format to be supported.
     */
    public static final String MDX_VERSION = "com.etas.ascet.build.mdx.version";
    public static final String MDX_VERSION_V130 = "1.3.0";

    /**
     * Value <code>true</code>/<code>false</code><br/>
     * If <code>true</code> the generated source code is put into the generated FMU package.
     */
    public static final String FMU_INCLUDE_SOURCE_CODE = "com.etas.ascet.build.include.source.code";
    public static final String FMU_MODEL_IDENTENTIFIER_SUFFIX_CO_SIMULATION =
            "com.etas.ascet.build.model.identifier.suffix.co.simulation";
    public static final String SIMULATION_ENABLE_MEASUREMENTS = "com.etas.ascet.build.simulation.enable.measurements";
    public static final String SIMULATION_ENABLE_CALIBRATION = "com.etas.ascet.build.simulation.enable.calibration";

    /**
     * Value is one of the supported INTECRIO versions: "5.0", "4.7", "4.6"<br/>
     */
    public static final String INTECRIO_VERSION = "com.etas.ascet.build.prototype.intecrio.version";
    /**
     * Path to INTECRIO workspace, e.g. "${workspace_loc}\\Intecrio\\intecrio.iow"
     */
    public static final String INTECRIO_WORKSPACE = "com.etas.ascet.build.prototype.intecrio.workspace";
    public static final String INTECRIO_SYSTEM = "com.etas.ascet.build.prototype.intecrio.system";
    public static final String INTECRIO_BUILD = "com.etas.ascet.build.prototype.intecrio.build";

    /**
     * Value one of the constants TARGET_INT_DIV_ROUNDING_*<br/>
     * Defines the rounding strategy
     */
    public static final String TARGET_INT_DIV_ROUNDING = "com.etas.ascet.build.target.integerDivisionRounding";
    /**
     * Can be used as option for {@link #TARGET_INT_DIV_ROUNDING}
     */
    public static final String TARGET_INT_DIV_ROUNDING_TRUNCATE = "truncate";
    /**
     * Can be used as option for {@link #TARGET_INT_DIV_ROUNDING}
     */
    public static final String TARGET_INT_DIV_ROUNDING_FLOOR = "floor";
    /**
     * Can be used as option for {@link #TARGET_INT_DIV_ROUNDING}
     */
    public static final String TARGET_INT_DIV_ROUNDING_CEIL = "ceil";

    /**
     * Value one of the constants TARGET_WORD_SIZE_*<br/>
     * Defines the bit size of the target.
     */
    public static final String TARGET_WORD_SIZE = "com.etas.ascet.build.target.wordSize";
    /**
     * Can be used as option for {@link #TARGET_WORD_SIZE}
     */
    public static final String TARGET_WORD_SIZE_BIT_16 = "16";
    /**
     * Can be used as option for {@link #TARGET_WORD_SIZE}
     */
    public static final String TARGET_WORD_SIZE_BIT_32 = "32";

    /**
     * defines a list of space separated C-defines
     */
    public static final String TARGET_COMPILER_DEFINES = "com.etas.ascet.build.compiler.defines";
    public static final String CALLBACK_ARITHMETIC_SERVICE_PATH =
            "com.etas.ascet.build.arithmetic.service.definitionPath";
    public static final String CALLBACK_OPTION_STANDARD_ARITHMETIC =
            "com.etas.ascet.build.arithmetic.service.replaceStandard";

    public static final String OPTIONS_INLINE_ESDL_IN_GENERATED_C = "com.etas.ascet.build.inline.esdl";
    public static final String OPTIONS_RESOLVE_CCODE_VARIANT = "com.etas.ascet.build.resolveCCodeVariant";
    public static final String OPTIONS_DEFAULT_INTEGER_ELEMENT_LENGTH =
            "com.etas.ascet.build.defaultIntegerElementLength";
    public static final String OPTIONS_DEFAULT_REAL_TYPE = "com.etas.ascet.build.defaultFloatingPointPrecision";

    public static final String MCDC_COVERAGE_ENABLEMENT = "com.etas.ascet.build.mcdc.coverage.enablement";
    public static final String ASAM_CODE_SYNTAX_PATH = "com.etas.ascet.build.asam.mdx.code.syntax.definitionPath";

    public static final String LOG_FILE = "org.eclipse.debug.ui.ATTR_CAPTURE_IN_FILE";

}
