package com.etas.ascet.api.v1.datatype;

import java.math.BigDecimal;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * A to calculate the encoded value from the physical value.
 * The physical value is the value from the model. The encoded value the number in the generated ECU code, that might be
 * quantized.
 *
 * <pre>
 * encoded = physical × x1 + x0
 * </pre>
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class FormulaDtoV1 {

    public abstract IdentifierDtoV1 identifier();

    /**
     * Offset value.
     *
     * @see FormulaDtoV1
     */
    public abstract BigDecimal x0();

    /**
     * Scale factor value.
     *
     * @see FormulaDtoV1
     */
    public abstract BigDecimal x1();

    public static Builder builder() {
        return new AutoValue_FormulaDtoV1.Builder()
                .x0(BigDecimal.ZERO)
                .x1(BigDecimal.ONE);
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see FormulaDtoV1#identifier()
         */
        Builder identifier(IdentifierDtoV1 value);

        /**
         * @see FormulaDtoV1#x0()
         */
        Builder x0(BigDecimal value);

        /**
         * @see FormulaDtoV1#x1()
         */
        Builder x1(BigDecimal value);

        FormulaDtoV1 build();
    }
}
