package com.etas.ascet.api.v1.datatype;

import org.apache.commons.lang3.StringUtils;
import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * Capable of identification of a model element in a certain workspace.
 * Only the internalReference is evaluated by ASCET when then identifier is passed in as an argument.
 * The other fields are for information on the client side.
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class IdentifierDtoV1 {
    /**
     * reference to the internal entity in ASCET-DEVELOPER.
     * The reference shall not be decoded or composed or persisted by the client.
     */
    public abstract String internalReference();

    public abstract String qualifiedName();

    public abstract String simpleName();

    public abstract String projectName();

    public static final String IDENTIFIER_TYPE_MODEL_CLASS = "model-class";
    public static final String IDENTIFIER_TYPE_MODEL_STRUCT = "model-stuct";

    public static final String IDENTIFIER_TYPE_TARGET_APPLICATION = "target-application";
    public static final String IDENTIFIER_TYPE_TARGET_APPLICATION_ENTRY_POINT = "target-application-entry-point";
    public static final String IDENTIFIER_TYPE_TARGET_APPLICATION_TASK = "target-application-task";

    public static final String IDENTIFIER_TYPE_TARGET_CLASS = "target-class";
    public static final String IDENTIFIER_TYPE_TARGET_METHOD = "target-method";
    public static final String IDENTIFIER_TYPE_TARGET_STRUCT = "target-struct";
    public static final String IDENTIFIER_TYPE_TARGET_DATA_INTERFACE = "target-data-interface";

    public static final String IDENTIFIER_TYPE_TARGET_INSTANCE = "target-instance";

    /**
     * @apiNote enums are not part of the scalar types
     * @see #IDENTIFIER_TYPE_ENUM
     */
    public static final String IDENTIFIER_TYPE_SCALAR = "scalar-type";
    public static final String IDENTIFIER_TYPE_ENUM = "enum";
    public static final String IDENTIFIER_TYPE_ARRAY = "array-type";
    public static final String IDENTIFIER_TYPE_TABLE = "table-type";
    public static final String IDENTIFIER_TYPE_AXIS = "axis-type";
    public static final String IDENTIFIER_TYPE_FORMULA = "formula";

    public static final String IDENTIFIER_TYPE_UNIT = "unit";

    public abstract String identifierType();

    /**
     * The name of the used representation or empty string
     */
    public abstract String representationName();

    public static Builder builder() {
        return new AutoValue_IdentifierDtoV1.Builder()
                .representationName(StringUtils.EMPTY);
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * see {@link IdentifierDtoV1#internalReference()}
         */
        Builder internalReference(String value);

        /**
         * see {@link IdentifierDtoV1#qualifiedName()}
         */
        Builder qualifiedName(String value);

        /**
         * see {@link IdentifierDtoV1#simpleName()}
         */
        Builder simpleName(String value);

        /**
         * see {@link IdentifierDtoV1#projectName()}
         */
        Builder projectName(String value);

        /**
         * see {@link IdentifierDtoV1#identifierType()}
         */
        Builder identifierType(String value);

        /**
         * see {@link IdentifierDtoV1#representationName()}
         */
        Builder representationName(String value);

        IdentifierDtoV1 build();
    }

}
