package com.etas.ascet.api.v1.datatype;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class LaunchCopyRequestDtoV1 {

    /**
     * The name of the launch configuration to be copied, as it is visible in the tree of the "Run ..." dialog.
     */
    public abstract String sourceLaunchName();

    /**
     * The target name of the launch configuration, as it will be visible in the tree of the "Run ..." dialog.
     * This name must be unique. If it already exists, a unique name is created. See the result value.
     */
    public abstract String targetLaunchName();

    /**
     * The workspace path of the project or directory in which the launch config shall be saved to.
     * If this is empty, the launch config is not saved to file, but stored in the workspace only.
     */
    public abstract String targetFileContainer();

    public static Builder builder() {
        return new AutoValue_LaunchCopyRequestDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see LaunchCopyRequestDtoV1#sourceLaunchName()
         */
        Builder sourceLaunchName(String value);

        /**
         * @see LaunchCopyRequestDtoV1#targetLaunchName()
         */
        Builder targetLaunchName(String value);

        /**
         * @see LaunchCopyRequestDtoV1#targetFileContainer()
         */
        Builder targetFileContainer(String value);

        LaunchCopyRequestDtoV1 build();
    }
}
