package com.etas.ascet.api.v1.datatype;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * Representation information that is associated with a scalar instance.
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class ScalarRepresentationDtoV1 {

    /**
     * Formula to calculate the represented value from the model value
     */
    @Nullable
    public abstract FormulaDtoV1 formula();

    /**
     * The represented type, e.g. "float32", "sint32" or for enum "example_Mode"
     */
    public abstract String typeName();

    /**
     * The binary type, e.g the pimitiveType of an enum might be {@link PrimitiveTypeV1#UINT8}
     */
    public abstract PrimitiveTypeV1 primitiveType();

    /**
     * The min/max range in the generated code.
     */
    public abstract NumberRangeDtoV1 numberRange();

    public static Builder builder() {
        return new AutoValue_ScalarRepresentationDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see ScalarRepresentationDtoV1#formula()
         */
        Builder formula(@Nullable FormulaDtoV1 value);

        /**
         * @see ScalarRepresentationDtoV1#typeName()
         */
        Builder typeName(String value);

        /**
         * @see ScalarRepresentationDtoV1#primitiveType()
         */
        Builder primitiveType(PrimitiveTypeV1 value);

        /**
         * @see ScalarRepresentationDtoV1#numberRange()
         */
        Builder numberRange(NumberRangeDtoV1 value);

        ScalarRepresentationDtoV1 build();
    }
}
