package com.etas.ascet.api.v1.datatype;

import java.util.List;

import org.eclipse.jdt.annotation.NonNullByDefault;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * Data of an ASCET application (.app file)
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class TargetApplicationDtoV1 {

    public abstract IdentifierDtoV1 identifier();

    /**
     * List of entry points of an ASCET application.
     * An entry point is a static class or a singleton class instance that can optionally have a representation
     * and/or an initializer.
     */
    public abstract List<IdentifierDtoV1> entryPoints();

    /**
     * List of tasks, where each task has timing information and a list of processes that is executed.
     */
    public abstract List<ApplicationTaskDtoV1> schedule();

    public static Builder builder() {
        return new AutoValue_TargetApplicationDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see TargetApplicationDtoV1#identifier()
         */
        Builder identifier(IdentifierDtoV1 value);

        /**
         * @see TargetApplicationDtoV1#entryPoints()
         */
        Builder entryPoints(List<IdentifierDtoV1> value);

        /**
         * @see TargetApplicationDtoV1#schedule()
         */
        Builder schedule(List<ApplicationTaskDtoV1> value);

        TargetApplicationDtoV1 build();
    }
}
