package com.etas.ascet.api.v1.datatype;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

// Checkstyle:off
/**
 * A further specification of {@link TargetTypeDtoV1}
 */
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class TargetScalarTypeDtoV1 {

    public abstract IdentifierDtoV1 identifier();

    /**
     * If this is a derived type, then super type is the type this type is derived from.
     */
    @Nullable
    public abstract IdentifierDtoV1 superType();

    /**
     * The model number range of derived types with a range.
     * For the bare model types {@code real/integer} this is the open range.
     * For {@code boolean} it is [0 .. 1].
     */
    public abstract NumberRangeDtoV1 numberRange();

    /**
     * In case of no available representation the generated type to be used.
     */
    public abstract PrimitiveTypeV1 defaultRepresentedType();

    public static Builder builder() {
        return new AutoValue_TargetScalarTypeDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see TargetScalarTypeDtoV1#identifier()
         */
        Builder identifier(IdentifierDtoV1 value);

        /**
         * @see TargetScalarTypeDtoV1#superType()
         */
        Builder superType(@Nullable IdentifierDtoV1 value);

        /**
         * @see TargetScalarTypeDtoV1#numberRange()
         */
        Builder numberRange(NumberRangeDtoV1 value);

        /**
         * @see TargetScalarTypeDtoV1#defaultRepresentedType()
         */
        Builder defaultRepresentedType(PrimitiveTypeV1 value);

        TargetScalarTypeDtoV1 build();
    }
}
