package com.etas.ascet.api.v1.datatype;

import org.eclipse.jdt.annotation.NonNullByDefault;
import org.eclipse.jdt.annotation.Nullable;

import com.google.auto.value.AutoValue;
import com.ryanharter.auto.value.gson.GenerateTypeAdapter;

/**
 * The concrete type of a {@link TargetInstanceDtoV1}
 */
// Checkstyle:off
@NonNullByDefault
@GenerateTypeAdapter
@AutoValue
public abstract class TargetTypeDtoV1 {

    /**
     * The unique identifier of this type, which is especially linked to {@link TargetInstanceDtoV1#type()},
     * but also to deriving types, e.g. {@link TargetScalarTypeDtoV1#superType()}.
     */
    public abstract IdentifierDtoV1 identifier();

    /**
     * The kind of the type, SCALAR or ENUM or ...
     */
    public abstract TypeKindV1 kind();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is SCALAR, then this is filled.
     */
    @Nullable
    public abstract TargetScalarTypeDtoV1 scalarType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is ENUM, then this is filled.
     */
    @Nullable
    public abstract TargetEnumTypeDtoV1 enumType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is STRUCT, then this is filled.
     */
    @Nullable
    public abstract TargetStructTypeDtoV1 structType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is CLASS, then this is filled.
     */
    @Nullable
    public abstract TargetClassTypeDtoV1 classType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is DATA_INTERFACE, then this is filled.
     */
    @Nullable
    public abstract TargetDataInterfaceTypeDtoV1 dataInterfaceType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is ARRAY, then this is filled.
     */
    @Nullable
    public abstract TargetArrayTypeDtoV1 arrayType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is TABLE, then this is filled.
     */
    @Nullable
    public abstract TargetTableTypeDtoV1 tableType();

    /**
     * Exactly one of the types is filled. If {@link #kind()} is AXIS, then this is filled.
     */
    @Nullable
    public abstract TargetAxisTypeDtoV1 axisType();

    public static Builder builder() {
        return new AutoValue_TargetTypeDtoV1.Builder();
    }

    @AutoValue.Builder
    public interface Builder {

        /**
         * @see TargetTypeDtoV1#identifier()
         */
        Builder identifier(IdentifierDtoV1 value);

        /**
         * @see TargetTypeDtoV1#kind()
         */
        Builder kind(TypeKindV1 value);

        /**
         * @see TargetTypeDtoV1#scalarType()
         */
        Builder scalarType(@Nullable TargetScalarTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#enumType()
         */
        Builder enumType(@Nullable TargetEnumTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#structType()
         */
        Builder structType(@Nullable TargetStructTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#classType()
         */
        Builder classType(@Nullable TargetClassTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#dataInterfaceType()
         */
        Builder dataInterfaceType(@Nullable TargetDataInterfaceTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#arrayType()
         */
        Builder arrayType(@Nullable TargetArrayTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#tableType()
         */
        Builder tableType(@Nullable TargetTableTypeDtoV1 value);

        /**
         * @see TargetTypeDtoV1#axisType()
         */
        Builder axisType(@Nullable TargetAxisTypeDtoV1 value);

        TargetTypeDtoV1 build();
    }
}
