/* RegistryException.java
 *
 * jRegistryKey - A JNI wrapper of the Windows Registry functions.
 * Copyright (c) 2001, BEQ Technologies Inc.
 * 9407 - 27 Avenue
 * Edmonton, Alberta
 * T6N - 1L9 Canada
 * (780) 430-0056
 * (780) 437-6121 (fax)
 * http://www.beq.ca
 *
 * Original Author: Joe Robinson <joe@beq.ca>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package ca.beq.util.win32.registry;

/**
 * <code>RegistryException</code> signals that a registry operation has failed.
 *
 * @see java.lang.RuntimeException
 *
 * @author BEQ Technologies Inc.
 * @version $Revision: 1.5 $
 * <pre>
 * $Id: RegistryException.java,v 1.5 2004/12/20 21:21:30 bayblade Exp $
 * 
 * $Log: RegistryException.java,v $
 * Revision 1.5  2004/12/20 21:21:30  bayblade
 * Revampled initialization process so 1.0 upgraders weren't so confused;  fixed bug with IBM machines; and accidentally reverted to ANSI formatting instead of K&R in a few spots
 *
 * Revision 1.4  2004/04/20 00:16:18  bayblade
 * Added &lt;pre&gt; tags in headers so change history log 
 * can be sensibly read from javadoc
 *
 * Revision 1.3  2004/04/13 19:17:33  mollinie
 * Call to constructors of the class will fail unless initialization succeeded (in order
 * to enforce the initialize-before-use policy).
 *
 * Revision 1.2  2004/03/27 01:01:01  mollinie
 * Preliminary reformating.
 *
 * Revision 1.1.1.1  2004/03/25 22:05:38  bayblade
 * Initial Import
 * </pre>
 */

public class RegistryException extends RuntimeException {


    /** <code>serialVersionUID</code> to make 1.5 compilers happy */
    private static final long serialVersionUID = 3257848800692287801L;


    /**
     * Constructs a new <code>RegistryException</code> with no detail message.
     */
    public RegistryException() {
        super();
    }


    /**
     * Constructs a new <code>RegistryException</code> with the specified detail
     * message.
     *
     * @param msg the detail message.
     */
    public RegistryException( String msg ) {
        super( msg );
    }
}
