package ca.beq.util.win32.registry;
/**
 * <code>Win32Exception</code> is a special case of RegistryException where the 
 * error stems from a non-success result to a call to something in the WIN32 API
 * (specifically one of many registry API calls) 
 *
 * @see RegistryException
 *
 * @author Matt Hilliard
 * @version $Revision: 1.5 $
 * <pre>
 * $Id: Win32Exception.java,v 1.5 2006/10/04 07:36:16 bayblade Exp $
 * 
 * $Log: Win32Exception.java,v $
 * Revision 1.5  2006/10/04 07:36:16  bayblade
 * suitpd typoees
 *
 * Revision 1.4  2006/10/04 06:49:28  bayblade
 * Have some comments!
 *
 * </pre>
 */
public class Win32Exception extends RegistryException {

    private int errCode;

    /**
     * 
     */
    private static final long serialVersionUID = 3257848800692287811L;

    /**
     * Constructs a new <code>RegistryException</code> with no detail message.
     */
    public Win32Exception() {
        super();
    }

    /**
     * Constructs a new <code>RegistryException</code> with the specified return 
     * code.
     *
     * @param errCode the code returned from the win32 API registry call.
     */
    public Win32Exception( int errCode ) {
        super( lookupError( errCode ) );
        this.errCode = errCode;
    }

    private static native String lookupError( int errCode );

    /**
     * Check the error code returned from the win32 API registry call.
     */
    public int getErrCode() {
        return errCode;
    }
}
