/* jRegistryKey.h
 *
 * jRegistryKey - A JNI wrapper of the Windows Registry functions.
 * Copyright (c) 2001, BEQ Technologies Inc.
 * 9407 - 27 Avenue
 * Edmonton, Alberta
 * T6N - 1L9 Canada
 * (780) 430-0056
 * (780) 437-6121 (fax)
 * http://www.beq.ca
 *
 * Original Author: Joe Robinson <joe@beq.ca>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author BEQ Technologies Inc.
 * @version $Revision: 1.11 $
 * 
 * $Id: jRegistryKey.h,v 1.11 2007/03/04 02:30:58 bayblade Exp $
 * 
 * $Log: jRegistryKey.h,v $
 * Revision 1.11  2007/03/04 02:30:58  bayblade
 * New K&R indentation.
 *
 * Revision 1.10  2006/07/10 01:42:17  bayblade
 * Introducing Win32Exception ...
 * Subclassed RegistryException with new Win32Exception that contains the windows error message, and a method to see the error code as an int rather than a formatted string containing the error code.  The exception message is different, which may break logic that parses this message, but explicitly catching the subclass now allows for greater refinement when processing what actually broke, and is a better solution overall.
 *
 * Revision 1.9  2006/06/11 16:46:53  bayblade
 * Introducing Win32Exception ...
 * Subclassed RegistryException with new Win32Exception that contains the windows error message, and a method to see the error code as an int rather than a formatted string containing the error code.  The exception message is different, which may break logic that parses this message, but explicitly catching the subclass now allows for greater refinement when processing what actually broke, and is a better solution overall.
 *
 * Revision 1.8  2005/05/10 01:01:46  bayblade
 * 3 things happened here: added support for reg_qword, support for reg_multi_sz and finally unhooped unicode character conversion.
 *
 * Revision 1.7  2005/02/03 00:08:59  bayblade
 * Cleaned up remnants from recent bug fixes.
 *
 * Revision 1.6  2005/01/25 22:41:29  bayblade
 * Most noticaly, the fix for 1105000 which both reworks the Unicode to UTF-8 mechanism and permits REG_SZ data to run through the system as byte[] (though byte[] defaults to REG_BINARY)
 *
 * Revision 1.5  2004/10/28 19:30:21  bayblade
 * Added and began using jstringToWindows() method by David Wendt (wendt@us.ibm.com)
 *
 * Revision 1.4  2004/04/19 22:00:58  bayblade
 * Added preliminary build changes for a MinGW compilation of the native DLL.
 * Issuing "ant gnubuild" will use the gnu compiler rather than the msvc one.
 *
 * Revision 1.3  2004/04/06 18:18:23  mollinie
 * Added a parameter to custom function openKey of type REGSAM to indicate what rights to open a key with.
 *
 * Revision 1.2  2004/04/02 23:54:47  mollinie
 * Extracted the common code to extract rootKey and key path and open key into a common method openKey.
 * Moved utility functions prototypes to header jRegistryKey.h
 *
 * Revision 1.1  2004/03/31 23:16:22  mollinie
 * Re-organized the native code organization and build process.
 *
 * Revision 1.1.1.1  2004/03/25 22:05:38  bayblade
 * Initial Import
 *
 */

#ifndef jRegistryKeyH_
#define jRegistryKeyH_

#include "jni.h"

/**
 * Utility functions prototypes.
 */
HKEY getRootKey(JNIEnv *, jobject);
HKEY openKey(JNIEnv *, jobject, REGSAM);
const wchar_t* jstringToWindows( JNIEnv *, jstring jstr );
jstring windowsToJString( JNIEnv *, const wchar_t* str );
void throwWin32( JNIEnv * env, jint status );
/**
 * jRegistryKey.h provides a wrapper for the class and field descriptors of the
 * classes used in the ca.beq.util.win32.registry package.
 */
namespace registryDescriptor {
static char* const jcd_KeyIterator        = "ca/beq/util/win32/registry/KeyIterator";
static char* const jcd_RegistryException  = "ca/beq/util/win32/registry/RegistryException";
static char* const jcd_Win32Exception     = "ca/beq/util/win32/registry/Win32Exception";
static char* const jcd_RegistryKey        = "ca/beq/util/win32/registry/RegistryKey";
static char* const jcd_RegistryValue      = "ca/beq/util/win32/registry/RegistryValue";
static char* const jcd_RootKey            = "ca/beq/util/win32/registry/RootKey";
static char* const jcd_ValueIterator      = "ca/beq/util/win32/registry/ValueIterator";
static char* const jcd_ValueType          = "ca/beq/util/win32/registry/ValueType";

static char* const jfd_KeyIterator        = "Lca/beq/util/win32/registry/KeyIterator;";
static char* const jfd_RegistryException  = "Lca/beq/util/win32/registry/RegistryException;";
static char* const jfd_Win32Exception     = "Lca/beq/util/win32/registry/Win32Exception";
static char* const jfd_RegistryKey        = "Lca/beq/util/win32/registry/RegistryKey;";
static char* const jfd_RegistryValue      = "Lca/beq/util/win32/registry/RegistryValue;";
static char* const jfd_RootKey            = "Lca/beq/util/win32/registry/RootKey;";
static char* const jfd_ValueIterator      = "Lca/beq/util/win32/registry/ValueIterator;";
static char* const jfd_ValueType          = "Lca/beq/util/win32/registry/ValueType;";
};

#endif // jRegistryKeyH_
